pub struct NodeBody {
pub layout: NodeLayout,
pub background_color: Color,
pub padding: Padding,
pub socket_text_gap: f32,
pub column_gap: f32,
}Expand description
Defines how the node body should be rendered.
Fields
layout: NodeLayoutThe layout for the sockets.
background_color: ColorThe background color.
padding: PaddingThe padding of the body.
socket_text_gap: f32The space between a socket shape and its name text.
column_gap: f32The space between the two columns when layout is NodeLayout::Double.